@@ -71,6 +71,11 @@ __END__
 
 Search::Kinosearch::Doc - a document.
 
+=head1 DEPRECATED
+
+Search::Kinosearch has been superseded by L<KinoSearch|KinoSearch>.  Please
+use the new version.
+
 =head1 SYNOPSIS
 
     my $kindexer = Search::Kinosearch::Kindexer->new;
